@@ -59,7 +59,7 @@ class Selenese(object):
     # Actions
 
     def pause(self, milliseconds):
-        time.sleep(milliseconds / 1000)
+        time.sleep(milliseconds / 1000.0)
 
     def setTimeout(self, timeout):
         self.timeout = timeout / 1000.0
@@ -126,6 +126,10 @@ class Selenese(object):
         self.click(locator)
         self.waitForPageToLoad()
 
+    @passthrough
+    def clickAt(self, locator, coordString):
+        pass
+
     @passthrough
     def chooseCancelOnNextConfirmation(self):
         pass
@@ -214,6 +218,10 @@ class Selenese(object):
     def typeKeys(self):
         pass
 
+    @passthrough
+    def runScript(self, script):
+        pass
+
     # Getter
 
     @assert_type('pattern')
@@ -256,6 +264,21 @@ class Selenese(object):
     def getSelectedLabel(self, locator):
         pass
 
+    @assert_type('locator_pattern')
+    @passthrough
+    def getSelectedValue(self, locator):
+        pass
+
+    @assert_type('locator_pattern')
+    @passthrough
+    def getSelectedIndex(self, locator):
+        pass
+
+    @assert_type('locator')
+    @passthrough
+    def isChecked(self, locator):
+        pass
+
     @assert_type('locator_pattern')
     @passthrough
     def getText(self, locator):
@@ -291,6 +314,7 @@ class Selenese(object):
     def isTextPresent(self, pattern):
         pass
 
+    @assert_type('pattern')
     @passthrough
     def getLocation(self):
         pass
@@ -310,7 +334,7 @@ class Selenese(object):
 
     def assertXpathCount(self, xpath, count):
         result = self.selenium.get_xpath_count(xpath)
-        if result != count:
+        if int(result) != int(count):
             raise self.failureException(
                 'Actual count of XPath %r is %s, expected %s'
                 % (xpath, result, count))
